<?php
 /** @package Garennes - Fonctions de gestion des fichiers XML */
 
 /**
 * Variable globale pour creation structure
 * @global array $table_xml
   [0] = Debut
   [1] = Fin
 */

 
 /**
 * Fonction de creation d'une structure
 * @param string $version Version du XML
 * @param string $table_caracteres Nom de la table de caracteres utilise
 * @return array Tableau XML
 */
 Function garennes_xml_creation ($version, $table_caracteres)
  {
   $table [0] = "<?xml" ;
   If ($version != "") { $table [0] .= " version=\"".$version."\"" ; }
   If ($table_caracteres != "") { $table [0] .= " encoding=\"".$table_caracteres."\"" ; }
   $table [0] .= " ?>" ;
   $table [1] .= "" ;
   Return $table ;
  }
 
 /**
 * Fonction de creation d'un noeud
 * @param string $nom Nom du noeud
 * @param array $attributs Table des attributs
 *                         [0][0]=Nombre
 *                         [i][0]=Nom
 *                         [i][1]=Valeur
 * @param array $noeuds Table des noeuds contenus
 *                         [0][0]=Nombre
 *                         [i][0]=Debut
 *                         [i][1]=Fin
 * @param string $noeuds Chaine de caracteres, valeur du noeud
 * @return array tableau XML
 */
 Function garennes_xml_noeud ($nom, $attributs, $noeuds)
  {
   $table [0] = "<".$nom ;
   If ($attributs [0][0] > 0)
    {
     For ($i = 1 ; $i <= $attributs [0][1] ; $i++)
      {
       $table [0] .= " ".$attributs [$i][0]."=\"".$attributs [$i][1]."\"" ;
      }
    }
   If (Is_Array ($noeuds))
    {
     If ($noeuds [0][0] > 0)
      {
       $table [0] .= ">" ;
       For ($i = 1 ; $i <= $noeuds [0][0] ; $i++)
        {
         $table [0] .= $noeuds [$i][0] ;
         $table [1] = $noeuds [$i][1].$table [1] ;
        }
      }
     Else { $table [0] .= "/>" ; }
     $table [1] = "" ;
    }
   Else
    {
     If ($noeuds != "") { $table [0] .= ">".$noeuds."</".$nom.">" ; }
     Else { $table [1] = "</".$nom.">" ; }
    }
   Return $table ;
  }

 /*
 * Generation du fichier XML pour exportation APB pour un etablissement
 * @param string $garennes_version Version du logiciel
 * @param array $etablissement Caracteristiques etablisement
 * @param array $classes Caracteristiques des classes
 * @param array $notes Caracteristiques des notes
 * @param array $matieres Caracteristiques des matieres
 * @param array $eleves Caracteristiques des eleves
 * @return string XML genere
 */
 Function garennes_generation_apb ($garennes_version, $etablissement, $classes, $notes, $matieres, $enseignants, $eleves)
  {
   $xml = New DOMDocument ('1.0','iso-8859-15') ;

   // ----------------------------------------------------------------------------
   // Racine : Fichier
   $racine = $xml->createElement ('fichier') ;
   $xml->appendChild ($racine) ;
   
   $racine_logiciel = $xml->createAttribute ('logiciel') ;
   $racine_version = $xml->createAttribute ('version') ;
   $racine_date_creation = $xml->createAttribute ('date-creation') ;
   $racine->appendChild ($racine_logiciel) ;
   $racine->appendChild ($racine_version) ;
   $racine->appendChild ($racine_date_creation) ;
   
   $racine_logiciel_valeur = $xml->createTextNode ('garennes') ;
   $racine_version_valeur = $xml->createTextNode ($garennes_version) ;
   $racine_date_valeur = $xml->createTextNode (StrFTime ("%Y-%m-%d")) ;
   
   $racine_logiciel->appendChild ($racine_logiciel_valeur) ;
   $racine_version->appendChild ($racine_version_valeur) ;
   $racine_date_creation->appendChild ($racine_date_valeur) ;
   
   // ----------------------------------------------------------------------------
   // Etablissement
   $noeud_etablissement = $xml->createElement ('etablissement') ;
   $racine->appendChild ($noeud_etablissement) ;
   
   $etab_rne = $xml->createAttribute ('rne') ;
   $etab_nom = $xml->createAttribute ('nom') ;
   $etab_cp = $xml->createAttribute ('cp') ;
   $noeud_etablissement->appendChild ($etab_rne) ;
   $noeud_etablissement->appendChild ($etab_nom) ;
   $noeud_etablissement->appendChild ($etab_cp) ; 
   $etab_rne_valeur = $xml->createTextNode ($etablissement ['rne']) ;
   $etab_nom_valeur = $xml->createTextNode ($etablissement ['nom']) ;
   $etab_cp_valeur = $xml->createTextNode ($etablissement ['cp']) ;
   $etab_rne->appendChild ($etab_rne_valeur) ;
   $etab_cp->appendChild ($etab_cp_valeur) ;
   $etab_nom->appendChild ($etab_nom_valeur) ;
   
   // ----------------------------------------------------------------------------
   // Classes
   $noeud_classes = $xml->createElement ('classes') ;
   $noeud_etablissement->appendChild ($noeud_classes) ;
   
   ForEach ($classes as $cl)
    {
     $classe_courante = $xml->createElement ('classe') ;
     $noeud_classes->appendChild ($classe_courante) ;
     
     $cl_code = $xml->createAttribute ('code') ;
     $cl_code_valeur = $xml->createTextNode (PReg_Replace ('/ /', '', 'C-'.UTF8_Encode ($cl ['code']))) ;
     $classe_courante->appendChild ($cl_code) ;
     $cl_code->appendChild ($cl_code_valeur) ;
     
     $cl_annee = $xml->createAttribute ('annee') ;
     $cl_annee_valeur = $xml->createTextNode ($cl ['annee']) ;
     $classe_courante->appendChild ($cl_annee) ;
     $cl_annee->appendChild ($cl_annee_valeur) ;
     
     $cl_nom = $xml->createAttribute ('nom') ;
     $cl_nom_valeur = $xml->createTextNode (UTF8_Encode ($cl ['nom'])) ;
     $classe_courante->appendChild ($cl_nom) ;
     $cl_nom->appendChild ($cl_nom_valeur) ;
     
     $cl_niveau = $xml->createAttribute ('niveau') ;
     $cl_niveau_valeur = $xml->createTextNode (UTF8_Encode ($cl ['niveau'])) ;
     $classe_courante->appendChild ($cl_niveau) ;
     $cl_niveau->appendChild ($cl_niveau_valeur) ;
     
     // Inserer les profs principaux
     If ($cl ['prof_princ'] != "")
      {
       $cl_prof_princ = $xml->createAttribute ('professeur-principal') ;
       $cl_prof_princ_valeur = $xml->createTextNode ($cl ['prof_princ']) ;
       $classe_courante->appendChild ($cl_prof_princ) ;
       $cl_decoupage->appendChild ($cl_prof_princ_valeur) ;
      }

     $cl_decoupage = $xml->createAttribute ('decoupage') ;
     $cl_decoupage_valeur = $xml->createTextNode ($cl ['decoupage']) ;
     $classe_courante->appendChild ($cl_decoupage) ;
     $cl_decoupage->appendChild ($cl_decoupage_valeur) ;
    }
   
   // ----------------------------------------------------------------------------
   // Services notations
   $services_notations = $xml->createElement ('services-notations') ;
   $noeud_etablissement->appendChild ($services_notations) ;
   
   ForEach ($notes as $code => $sn)
    {
     // Note : csn pour current_service_notation
     $csn = $xml->createElement ('service-notation') ;
     $services_notations->appendChild ($csn) ;
     
     // On passe les attributs
     $snCode = $xml->createAttribute ('code') ;
     $snCode_valeur = $xml->createTextNode ('S-'.UTF8_Encode ($code)) ;
     $csn->appendChild ($snCode) ;
     $snCode->appendChild ($snCode_valeur) ;
     
     $snAnnee = $xml->createAttribute ('annee') ;
     $snAnnee_valeur = $xml->createTextNode (UTF8_Encode ($sn ['annee'])) ;
     $csn->appendChild ($snAnnee) ;
     $snAnnee->appendChild ($snAnnee_valeur) ;
     
     $snTrimestre = $xml->createAttribute ('trimestre') ;
     $snTrimestre_valeur = $xml->createTextNode (UTF8_Encode ($sn ['trimestre'])) ;
     $csn->appendChild ($snTrimestre) ;
     $snTrimestre->appendChild ($snTrimestre_valeur) ;
     
     $snCodeEnseignant = $xml->createAttribute ('code-enseignant') ;
     $snCodeEnseignant_valeur = $xml->createTextNode ('P-'.UTF8_Encode ($sn ['code-enseignant'])) ;
     $csn->appendChild ($snCodeEnseignant) ;
     $snCodeEnseignant->appendChild ($snCodeEnseignant_valeur) ;
     
     $snCodeMatiere = $xml->createAttribute ('code-matiere') ;
     $snCodeMatiere_valeur = $xml->createTextNode ('M-'.UTF8_Encode ($sn ['code-matiere'])) ;
     $csn->appendChild ($snCodeMatiere) ;
     $snCodeMatiere->appendChild ($snCodeMatiere_valeur) ;
     
     // Effectif
     If ($sn ['effectif'] != '0')
      {
       $effectif = $xml->createElement ('effectif') ;
       $csn->appendChild ($effectif) ;
       $effectif_valeur = $xml->createTextNode ($sn ['effectif']) ;
       $effectif->appendChild ($effectif_valeur) ;
      }
     // Moyenne classe
     If ($sn ['moyenne-classe'] != '')
      {
       $moyenne_classe = $xml->createElement ('moyenne-classe') ;
       $csn->appendChild ($moyenne_classe) ;
       $moyenne_classe_valeur = $xml->createTextNode ($sn ['moyenne-classe']) ;
       $moyenne_classe->appendChild ($moyenne_classe_valeur) ;
      }
     // Moyenne haute
     If ($sn ['moyenne-haute'] != '')
      {
       $moyenne_haute = $xml->createElement ('moyenne-haute') ;
       $csn->appendChild ($moyenne_haute) ;
       $moyenne_haute_valeur = $xml->createTextNode ($sn ['moyenne-haute']) ;
       $moyenne_haute->appendChild ($moyenne_haute_valeur) ;
      }
     // Moyenne basse
     If ($sn ['moyenne-basse'] != '')
      {
       $moyenne_basse = $xml->createElement ('moyenne-basse') ;
       $csn->appendChild ($moyenne_basse) ;
       $moyenne_basse_valeur = $xml->createTextNode ($sn ['moyenne-basse']) ;
       $moyenne_basse->appendChild ($moyenne_basse_valeur) ;
      }
    }

   // ----------------------------------------------------------------------------
   // Les matieres
   $noeud_matieres = $xml->createElement ('matieres') ;
   $noeud_etablissement->appendChild ($noeud_matieres) ;
   
   ForEach ($matieres as $matiere)
    {
     $mat = $xml->createElement ('matiere') ;
     $noeud_matieres->appendChild ($mat) ;
     
     // On passe les attributs
     $matCode = $xml->createAttribute ('code') ;
     $matCode_valeur = $xml->createTextNode ('M-'.UTF8_Encode ($matiere ['code'])) ;
     $mat->appendChild ($matCode) ;
     $matCode->appendChild ($matCode_valeur) ;

     $matCodeSconet = $xml->createAttribute ('code-sconet') ;
     $matCodeSconet_valeur = $xml->createTextNode (UTF8_Encode ($matiere ['code'])) ;
     $mat->appendChild ($matCodeSconet) ;
     $matCodeSconet->appendChild ($matCodeSconet_valeur) ;
     
     $matLibelle = $xml->createAttribute ('libelle') ;
     $matLibelle_valeur = $xml->createTextNode (UTF8_Encode ($matiere ['libelle'])) ;
     $mat->appendChild ($matLibelle) ;
     $matLibelle->appendChild ($matLibelle_valeur) ;
    }
   
   // ----------------------------------------------------------------------------
   // LANGUES VIVANTES : il va faut trouver un moyen de les caracteriser...
   // Ca risque de devoir passer par une configuration manuelle, soit au moment
   // de l'export, soit dans la configuration du module.
   // Pour l'instant, on exporte une langue vivante vide et non utilisee, pour
   // etre conforme au schema...
   $noeud_langues = $xml->createElement ('langues-vivantes') ;
   $noeud_etablissement->appendChild ($noeud_langues) ;
   
   $lv1 = $xml->createElement ('langue-vivante') ;
   $noeud_langues->appendChild ($lv1) ;
   $lv1Code = $xml->createAttribute ('code') ;
   $lv1Code_valeur = $xml->createTextNode ('LV-LV1-TEST') ;
   $lv1Libelle = $xml->createAttribute ('libelle') ;
   $lv1Libelle_valeur = $xml->createTextNode ('LV1 de Test') ;
   $lv1->appendChild ($lv1Code) ;
   $lv1Code->appendChild ($lv1Code_valeur) ;
   $lv1->appendChild ($lv1Libelle) ;
   $lv1Libelle->appendChild ($lv1Libelle_valeur) ;
   
   // ----------------------------------------------------------------------------
   // Les enseignants
   $noeud_enseignants = $xml->createElement ('enseignants') ;
   $noeud_etablissement->appendChild ($noeud_enseignants) ;
   
   ForEach ($enseignants as $prof)
    {
     $e = $xml->createElement ('enseignant') ;
     $noeud_enseignants->appendChild ($e) ;
     
     // On passe les attributs
     $eCode = $xml->createAttribute ('code') ;
     $eCode_valeur = $xml->createTextNode ('P-'.UTF8_Encode ($prof ['code'])) ;
     $e->appendChild ($eCode) ;
     $eCode->appendChild ($eCode_valeur) ;
   
     $eNom = $xml->createAttribute ('nom') ;
     $eNom_valeur = $xml->createTextNode (UTF8_Encode ($prof ['nom'])) ;
     $e->appendChild ($eNom) ;
     $eNom->appendChild ($eNom_valeur) ;
     
     $ePrenom = $xml->createAttribute ('prenom') ;
     $ePrenom_valeur = $xml->createTextNode (UTF8_Encode ($prof ['prenom'])) ;
     $e->appendChild ($ePrenom) ;
     $ePrenom->appendChild ($ePrenom_valeur) ;
    }
   
   // ----------------------------------------------------------------------------
   // Les eleves
   $noeud_eleves = $xml->createElement ('eleves') ;
   $noeud_etablissement->appendChild ($noeud_eleves) ;
   
   ForEach ($eleves as $el)
    {
     $e = $xml->createElement ('eleve') ;
     $noeud_eleves->appendChild ($e) ;
     
     // On passe les attributs
     $eCode = $xml->createAttribute ('code') ;
     $eCode_valeur = $xml->createTextNode ('E-'.UTF8_Encode ($el ['code'])) ;
     $e->appendChild ($eCode) ;
     $eCode->appendChild ($eCode_valeur) ;
   
     $eINE = $xml->createAttribute ('ine') ;
     $eINE_valeur = $xml->createTextNode (UTF8_Encode ($el ['ine'])) ;
     $e->appendChild ($eINE) ;
     $eINE->appendChild ($eINE_valeur) ;
   
     $eNom = $xml->createAttribute ('nom') ;
     $eNom_valeur = $xml->createTextNode (UTF8_Encode ($el ['nom'])) ;
     $e->appendChild ($eNom) ;
     $eNom->appendChild ($eNom_valeur) ;
     
     $ePrenom = $xml->createAttribute ('prenom') ;
     $ePrenom_valeur = $xml->createTextNode (UTF8_Encode ($el ['prenom'])) ;
     $e->appendChild ($ePrenom) ;
     $ePrenom->appendChild ($ePrenom_valeur) ;
     
     $eNaissance = $xml->createAttribute ('date-naissance') ;
     $eNaissance_valeur = $xml->createTextNode (UTF8_Encode ($el ['date-naissance'])) ;
     $e->appendChild ($eNaissance) ;
     $eNaissance->appendChild ($eNaissance_valeur) ;
     
     // On passe les annees scolaires
     $annees_scolaires = $xml->createElement ('annees-scolaires') ;
     $e->appendChild ($annees_scolaires) ;
     
     ForEach ($el ['annees-scolaires'] as $an)
      {
       $annee = $xml->createElement ('annee-scolaire') ;
       $annees_scolaires->appendChild ($annee) ;
       
       $anneeDescription = $xml->createAttribute ('annee') ;
       $anneeDescription_valeur = $xml->createTextNode (UTF8_Encode ($an ['annee'])) ;
       $annee->appendChild ($anneeDescription) ;
       $anneeDescription->appendChild ($anneeDescription_valeur) ;
       
       $anneeCodeClasse = $xml->createAttribute ('code-classe') ;
       $anneeCodeClasse_valeur = $xml->createTextNode (PReg_Replace ('/ /', '', 'C-'.UTF8_Encode ($an ['code-classe']))) ;
       $annee->appendChild ($anneeCodeClasse) ;
       $anneeCodeClasse->appendChild ($anneeCodeClasse_valeur) ;
       
       // Les bulletins pour l'annee consideree
       $bulletins = $xml->createElement ('bulletins') ;
       $annee->appendChild ($bulletins) ;
       
       ForEach ($an ['bulletins'] as $bulletin)
        {
         $b = $xml->createElement ('bulletin') ;
         $bulletins->appendChild ($b) ;
         
         $bTrimestre = $xml->createAttribute ('trimestre') ;
         $bTrimestre_valeur = $xml->createTextNode (UTF8_Encode ($bulletin ['trimestre'])) ;
         $b->appendChild ($bTrimestre) ;
         $bTrimestre->appendChild ($bTrimestre_valeur) ;
   
         // Les notes pour ce trimestre
         ForEach ($bulletin ['notes'] as $note)
          {
           $n = $xml->createElement ('notes') ;
           $b->appendChild ($n) ;
           
           $nServiceNotation = $xml->createAttribute ('code-service-notation') ;
           $nServiceNotation_valeur = $xml->createTextNode ('S-'.UTF8_Encode ($note ['code-service-notation'])) ;
           $n->appendChild ($nServiceNotation) ;
           $nServiceNotation->appendChild ($nServiceNotation_valeur) ;
           
           // Etat de la note
           $nEtat = $xml->createAttribute ('etat') ;
           $nEtat_valeur = $xml->createTextNode (UTF8_Encode ($note ['etat'])) ;
           $n->appendChild ($nEtat) ;
           $nEtat->appendChild ($nEtat_valeur) ;
           
           If ($note ['etat'] == 'S')
            {
             $nMoyenne = $xml->createElement ('moyenne') ;
             $nMoyenne_valeur = $xml->createTextNode (UTF8_Encode ($note ['moyenne'])) ;
             $n->appendChild ($nMoyenne) ;
             $nMoyenne->appendChild ($nMoyenne_valeur) ;
           
             $nRang = $xml->createElement ('rang') ;
             $nRang_valeur = $xml->createTextNode (UTF8_Encode ($note ['rang'])) ;
             $n->appendChild ($nRang) ;
             $nRang->appendChild ($nRang_valeur) ;
            }
           
           If ($note ['coefficient'] != '0.0')
            {
             $nCoefficient = $xml->createElement ('coefficient') ;
             $nCoefficient_valeur = $xml->createTextNode (UTF8_Encode ($note ['coefficient'])) ;
             $n->appendChild ($nCoefficient) ;
             $nCoefficient->appendChild ($nCoefficient_valeur) ;
            }
           $nAppreciation = $xml->createElement ('appreciation') ;
           $nAppreciation_valeur = $xml->createTextNode (UTF8_Encode ($note ['appreciation'])) ;
           $n->appendChild ($nAppreciation) ;
           $nAppreciation->appendChild ($nAppreciation_valeur) ;
          }
        }
      }
    }
   Return $xml->saveXML () ;
  }
?>